using New_College.IServices.BASE;
using New_College.Model.Models;
using System.Threading.Tasks;

namespace New_College.IServices
{	
	/// <summary>
	/// IT_LongIdMapServices
	/// </summary>	
    public interface IT_LongIdMapServices :IBaseServices<T_LongIdMap>
	{
		Task<bool> ImportEnrollmentBatch();
		Task<bool> ImportEnrollmentPlane();
		Task<bool> ImportEnrollmentPlanedesc();
		Task<bool> ImportBatchline();
		Task<bool> ImportBatchTypeInfo();
	}
}