using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using New_College.IRepository;
using New_College.IServices;
using New_College.Model;

namespace New_College.Api.Controllers.Back
{
    [Route("api/[controller]/[action]")]
    [ApiController]
    public class AutoController : ControllerBase
    {
        private readonly ITest_CycleTimeInfoServices test_CycleTimeInfoServices;
        private readonly ID_LongIdMapServices d_LongIdMapServices;
        private readonly IT_LongIdMapServices t_LongIdMapServices;
        private readonly    IT_EnrollmentPlaneServices t_EnrollmentPlaneServices;
        private readonly ID_UniversityServices d_UniversityServices;
        private readonly ID_MajorSalaryServices d_MajorSalaryServices;

        public AutoController(ITest_CycleTimeInfoServices ITest_CycleTimeInfoServices
            , ID_LongIdMapServices ID_LongIdMapServices
            , IT_LongIdMapServices IT_LongIdMapServices
            , IT_EnrollmentPlaneServices IT_EnrollmentPlaneServices
            , ID_UniversityServices ID_UniversityServices
            , ID_MajorSalaryServices ID_MajorSalaryServices)
        {

            test_CycleTimeInfoServices = ITest_CycleTimeInfoServices;
            d_LongIdMapServices = ID_LongIdMapServices;
            t_LongIdMapServices = IT_LongIdMapServices;
            t_EnrollmentPlaneServices = IT_EnrollmentPlaneServices;
            d_UniversityServices = ID_UniversityServices;
            d_MajorSalaryServices = ID_MajorSalaryServices;
        }
        #region old
        ///// <summary>
        ///// 生成周期
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> AutoCycleTime()
        //{
        //    var result = await test_CycleTimeInfoServices.AutoCycleTime();
        //    return new MessageModel<bool>()
        //    {
        //        success = result,
        //        response = result,
        //        msg = result == true ? "成功" : "失败"
        //    };
        //}

        ///// <summary>
        ///// 
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> Import()
        //{
        //    var result = await d_LongIdMapServices.Import();
        //    return new MessageModel<bool>()
        //    {
        //        success = true,
        //        msg = "成功",
        //        response = result
        //    };
        //}
        #endregion

        #region  new T
        ///// <summary>
        ///// EnrollmentBatch
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> ImportEnrollmentBatch()
        //{
        //    return new MessageModel<bool>()
        //    {
        //        success = true,
        //        msg = "成功",
        //        response = await t_LongIdMapServices.ImportEnrollmentBatch()
        //    };
        //}

        ///// <summary>
        ///// EnrollmentPlane
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> ImportEnrollmentPlane()
        //{
        //    return new MessageModel<bool>()
        //    {
        //        success = true,
        //        msg = "成功",
        //        response = await t_LongIdMapServices.ImportEnrollmentPlane()
        //    };
        //}

        ///// <summary>
        ///// EnrollmentPlanedesc
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> ImportEnrollmentPlanedesc()
        //{
        //    return new MessageModel<bool>()
        //    {
        //        success = true,
        //        msg = "成功",
        //        response = await t_LongIdMapServices.ImportEnrollmentPlanedesc()
        //    };
        //}

        ///// <summary>
        ///// Batchline
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> ImportBatchline()
        //{
        //    return new MessageModel<bool>()
        //    {
        //        success = true,
        //        msg = "成功",
        //        response = await t_LongIdMapServices.ImportBatchline()
        //    };
        //}

        ///// <summary>
        ///// BatchTypeInfo
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> ImportBatchTypeInfo()
        //{
        //    return new MessageModel<bool>()
        //    {
        //        success = true,
        //        msg = "成功",
        //        response = await t_LongIdMapServices.ImportBatchTypeInfo()
        //    };
        //}
        #endregion

        ///// <summary>
        ///// 2019上海招生分数更新
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> Import()
        //{
        //    var result = await t_EnrollmentPlaneServices.Import();
        //    return new MessageModel<bool>() { success = true };
        //}

        ///// <summary>
        ///// 下载图片
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<MessageModel<bool>> SaveImg()
        //{
        //    var result = await d_UniversityServices.SaveImg();
        //    return new MessageModel<bool>() { success = true, msg = "成功" };
        //}


        ///// <summary>
        ///// 专业薪酬
        ///// </summary>
        ///// <returns></returns>
        //[HttpPost]
        //public async Task<bool> Import()
        //{
        //    return await d_MajorSalaryServices.Import();
        //}
    }
}
